; -*- Lisp -*-
(in-package :maxima)

(defparameter *autoconf-variables-set* "@variables_set@")
(defparameter *autoconf-prefix* "/usr/local")
(defparameter *autoconf-exec_prefix* "/usr/local")
(defparameter *autoconf-package* "maxima")
(defparameter *autoconf-version* "5.25.1")
(defparameter *autoconf-libdir* "/usr/local/lib")
(defparameter *autoconf-libexecdir* "/usr/local/libexec")
(defparameter *autoconf-datadir* "/usr/local/share")
(defparameter *autoconf-infodir* "/usr/local/share/info")
(defparameter *autoconf-host* "i686-pc-linux-gnu")
(defparameter *autoconf-win32* "false")
(defparameter *autoconf-ld-flags* "")
 
(defparameter *maxima-source-root* "/home/robertdodier/tmp/maxima-git/maxima")
(defparameter *maxima-default-layout-autotools* "true")
